diff src/share/vm/opto/domgraph.cpp @ 23421:c1091733abe6

8011858: Use Compile::live_nodes() instead of Compile::unique() in appropriate places Reviewed-by: kvn, vlivanov Contributed-by: vlad.ureche@gmail.com
author zmajo
date Wed, 16 Sep 2015 11:09:09 +0200
parents 55fb97c4c58d
children b5f3a471e646
line wrap: on
line diff
--- a/src/share/vm/opto/domgraph.cpp	Sun Sep 06 05:02:06 2015 -0700
+++ b/src/share/vm/opto/domgraph.cpp	Wed Sep 16 11:09:09 2015 +0200
@@ -505,8 +505,8 @@
 // Perform DFS search.  Setup 'vertex' as DFS to vertex mapping.  Setup
 // 'semi' as vertex to DFS mapping.  Set 'parent' to DFS parent.
 int NTarjan::DFS( NTarjan *ntarjan, VectorSet &visited, PhaseIdealLoop *pil, uint *dfsorder) {
-  // Allocate stack of size C->unique()/8 to avoid frequent realloc
-  GrowableArray <Node *> dfstack(pil->C->unique() >> 3);
+  // Allocate stack of size C->live_nodes()/8 to avoid frequent realloc
+  GrowableArray <Node *> dfstack(pil->C->live_nodes() >> 3);
   Node *b = pil->C->root();
   int dfsnum = 1;
   dfsorder[b->_idx] = dfsnum; // Cache parent's dfsnum for a later use